<?php
/**
 * Plugin Name: Replace Domain for Slider Revolution
 * Plugin URI: https://blog.bshark.com/replace-domain-for-revolution-revolution
 * Description: A simple plugin to replace Slider Revolution domain or URL.
 * Version: 1.0
 * Author: Perry
 * Author URI: https://blog.bshark.com/
 * Text Domain: replace-domain-revslider
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Domain_URL_Replace_For_Rev {

    public function __construct() {
        add_action('admin_menu', [$this, 'register_submenu']);
        add_action('admin_post_replace_urls_revslider', [$this, 'handle_url_replacement']);
        add_action('admin_notices', [$this, 'admin_notice']);
    }

    public function register_submenu() {
        add_submenu_page(
            'tools.php',
            'Replace URL for Slider Revolution',
            'Replace URL for Slider Revolution',
            'manage_options',
            'replace-url-revslider',
            [$this, 'render_submenu']
        );
    }

    public function render_submenu() {
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <div style="background-color: #fffbcc; border: 1px solid #e6db55; padding: 10px; margin: 15px 0; border-radius: 4px;">
                <strong>Heads up!</strong> Before you make changes, please backup your database. If anything goes wrong, you can use the backup to restore your site.<br>
                <strong>Tip:</strong> Make sure the domain you enter look the same. For example, if you use "https://" in one, use it in the other too!
            </div>

            <form method="post" action="<?php echo esc_html(admin_url('admin-post.php')); ?>">
                <table class="form-table">
                    <tr>
                        <th><label>Old Url</label></th>
                        <td><input type="text" name="old_url" required class="regular-text" /></td>
                    </tr>
                    <tr>
                        <th><label>New Url</label></th>
                        <td><input type="text" name="new_url" required class="regular-text" /></td>
                    </tr>
                </table>
                <input type="hidden" name="action" value="replace_urls_revslider">
                <?php submit_button('Replace URLs'); ?>
            </form>
        </div>
        <?php
    }

    public function handle_url_replacement() {
        if (!isset($_POST['old_url']) || !isset($_POST['new_url'])) {
            wp_die('Invalid data provided.');
        }

        global $wpdb;

        $slides = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}revslider_slides", ARRAY_A);

        $updated_count = 0;

        foreach ($slides as $slide) {
            $params = json_decode($slide['params'], true);
            $layers = json_decode($slide['layers'], true);

            $updated_params = $this->replace_url_in_array($params, $_POST['old_url'], $_POST['new_url']);
            $updated_layers = $this->replace_url_in_array($layers, $_POST['old_url'], $_POST['new_url']);

            $data = [
                'params' => json_encode($updated_params),
                'layers' => json_encode($updated_layers),
            ];
            
            $result = $wpdb->update($wpdb->prefix . 'revslider_slides', $data, ['id' => $slide['id']]);
            if ($result) $updated_count++;
        }

        if ($updated_count > 0) {
            add_option('domain_url_replace_notice', 'URLs have been successfully replaced.', '', 'no');
        } else {
            add_option('domain_url_replace_notice', 'No URLs were replaced. Please check your input and try again.', '', 'no');
        }

        wp_redirect(admin_url('tools.php?page=replace-url-revslider'));
        exit;
    }

    public function admin_notice() {
    if ($notice = get_option('domain_url_replace_notice')) {
        $class = (strpos($notice, 'successfully') !== false) ? 'notice-success' : 'notice-error';
        echo "<div class='notice {$class} is-dismissible'><p>{$notice}</p></div>";
        delete_option('domain_url_replace_notice');
        }
    }


    private function replace_url_in_array($array, $old_url, $new_url) {
        array_walk_recursive($array, function (&$value) use ($old_url, $new_url) {
            $value = str_replace($old_url, $new_url, $value);
        });

        return $array;
    }
}

new Domain_URL_Replace_For_Rev();
?>
